.. include:: ../README.rst
    :start-line: 3


Full documentation
==================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    api


Changelog
=========

.. include:: ../CHANGES.rst
    :start-line: 3


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
